# disksurf

<p align='center'>
  <img src="HD163296_zeroth.png" width="793" height="549">
  <br>
  <a href='https://disksurf.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/disksurf/badge/?version=latest' alt='Documentation Status' />
  </a>
</p>

## What is it?

Functions to measure the height of optically thick emission, or photosphere, using the method presented in [Pinte et al. (2018)](https://ui.adsabs.harvard.edu/abs/2018A%26A...609A..47P/abstract), then use this information to reproject images into arbitrary angles. Very much a work in progress.

## How do I install it?

Grab the latest version from PyPI:

```
$ pip install disksurf
```

This has a couple of dependencies, namely [astropy](https://github.com/astropy/astropy) and [GoFish](https://github.com/richteague/gofish), which should be installed automatically if you don't have them.

## How do I use it?

Follow our [tutorials](https://disksurf.readthedocs.io/en/latest/tutorials/tutorial_1.html) for a quick guide on how to use `disksurf` with your own data.
